@@ -1,11 +1,6 @@
 
 #' Retrieve Nomis datasets
 #'
-#' @description Retrieves specific datasets from Nomis, based on their ID. To
-#' find dataset IDs, use [nomis_data_info()]. Datasets are retrived
-#' in csv format and parsed with the `read_csv` function from the
-#' `readr` package into a tibble, with all columns parsed as character
-#' columns.
 #'
 #' @description To find the code options for a given dataset, use
 #' [nomis_get_metadata()] for specific codes, and
@@ -156,8 +151,6 @@
 #'   measures = c(20100, 20201), sex = 5
 #' )
 #'
-#' tibble::glimpse(jobseekers_country)
-#'
 #' # Return data on Jobseekers Allowance for Wigan
 #' jobseekers_wigan <- nomis_get_data(
 #'   id = "NM_1_1", time = "latest",
@@ -165,8 +158,6 @@
 #'   measures = c(20100, 20201), sex = "5"
 #' )
 #'
-#' tibble::glimpse(jobseekers_wigan)
-#'
 #' # annual population survey - regional - employment by occupation
 #' emp_by_occupation <- nomis_get_data(
 #'   id = "NM_168_1", time = "latest",
@@ -177,8 +168,6 @@
 #'   )
 #' )
 #'
-#' tibble::glimpse(emp_by_occupation)
-#'
 #' # Deaths in 2016 and 2015 by three specified causes,
 #' # identified with nomis_get_metadata()
 #' death <- nomis_get_data("NM_161_1",
@@ -187,15 +176,11 @@
 #'   cause_of_death = c(10300, 102088, 270)
 #' )
 #'
-#' tibble::glimpse(death)
-#'
 #' # All causes of death in London in 2016
 #' london_death <- nomis_get_data("NM_161_1",
 #'   date = c("2016"),
 #'   geography = "2013265927", sex = 1, age = 0
 #' )
-#'
-#' tibble::glimpse(london_death)
 #' }
 #' \dontrun{
 #' # Results in an error because `measure` is mistaken for `measures`
@@ -323,6 +308,13 @@ nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
 
   first_df <- nomis_get_data_util(query)
 
+  if (is.null(first_df)) {
+    stop("The API request did not return any results. ",
+      "Please check your parameters.",
+      call. = FALSE
+    )
+  }
+
   names(first_df) <- toupper(names(first_df))
 
   if (nrow(first_df) <= 0) {
@@ -345,7 +337,7 @@ nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
       )
       message("This may cause timeout and/or automatic rate limiting.")
 
-      if (utils::menu(c("Yes", "No"),
+      if (menu(c("Yes", "No"),
         title = "Do you want to continue?"
       ) == 2) {
         stop(call. = FALSE)
